<?php
// Survey database interface class as intermediate for storing data from the site to the RDF database 
require_once 'rdfConstants.php';
// Include RAP Library to write RDF files
include(RDFAPI_INCLUDE_DIR . "RDFAPI.php");

/**
 * Description of User
 *
 * @author jkraaijeveld
 */

class User extends ResearchToolObject {

	//Static Database-related information.
	private static $filename = 'data/users/users.rdf';
    
    public $email;
    public $password;
    
    /**
     * Constructor of User
     * If the user does not yet exist in the database, call with null as first parameter
     */
    public function __construct($uid = null, $email = null, $password = null) {
        if(!isset($uid))
        {
             $uid = md5(uniqid(rand(), true));
        }
        $this->uid = $uid;
		$this->email = $email;
        $this->password = $password;
	}

	/**
	 * function save()
	 * Saves the current object into the database.
	 */
	public function save()
	{
		//Ensure the required folder exists.
		if(!is_dir('data/users/'))
			mkdir('data/users/');

		$model = ResearchToolObject::load(User::$filename);
        $resourceUser = new Resource(USER . '/' . $this->uid);
        //Remove the old value stored with the given id
        $model->subtract($model->find($resourceUser, null, null));

        $resourceUserType = new Resource(USER);
        $predicateRType = new Resource(RTYPE);
        $model->add(new Statement($resourceUser,$predicateRType,$resourceUserType));

        $literalUserID = new Literal($this->uid);
        $predicateUniqueID = new Resource(UID);
        $model->add(new Statement($resourceUser,$predicateUniqueID,$literalUserID));
        
        $literalUserName = new Literal($this->email);
        $predicateName = new Resource(EMAIL);
        $model->add(new Statement($resourceUser,$predicateName,$literalUserName));			

        $literalPassword = new Literal($this->password);
        $predicatePassword = new Resource(PASSWORD);
		$model->add(new Statement($resourceUser,$predicatePassword,$literalPassword));

		$model->saveAs(User::$filename, 'rdf');
		return true;
	}


	/**
	 * static function get($arguments)
	 * Gets the array of User objects belonging to arguments supplied.
	 * @param type $arguments : An array containing zero or more of the following keys:
	 * 							'uid', 'email', 'password'
	 */
	public static function get($arguments)
	{
	    $model = ResearchToolObject::load(User::$filename);
        //Create the querystring 
        $querystring = '
            PREFIX  predicates: <' . SURVEYTOOL_PREDICATES_NAMESPACE . '>
            PREFIX  resources: <' . SURVEYTOOL_RESOURCES_NAMESPACE . '>
            SELECT ?uid, ?email, ?password
            WHERE 	
            {
                    _user	predicates:resource_type	resources:user ;
					predicates:uid ?uid ;
					predicates:email ?email ;
					predicates:password ?password ;
					' . ResearchToolObject::createArguments($arguments) . '
            }';
        //Query the model
		$results = $model->sparqlQuery($querystring);
        $users = array();
        if(!empty($results))
        {
            //Run over all results and create appropriate User objects
            foreach($results as $result)
            { 
				$users[] = new User($result['?uid']->label, $result['?email']->label, $result['?password']->label);
            }
        }
        return $users;
	}
}

?>
